# ADAPT

**ADAPT** stands for **ADA**ptive **P**icking **T**oolbox. This package is a library
thought for seismologist and scientist that approach a seismic phase picking analysis.

This library aims to easening the creation of seismic catalogue by means of a semi-automated offline multi-phase repicking system.

*  AUTHOR: _Matteo Bagagli_

* VERSION: _0.0.1_

*    DATE: _06.2021 @ ETH-Zurich_


----------

## Setup

More info coming soon. The software is currently under submission process in peer-reviewd journal.
In the meantime it is distributed a useful magnitude calculation script/module with several functions for LocalMagnitude (ML) calculation [Richter 1935]

For the moment just type:
```python
$ pip install adapt
```

----------

#### References

- Richter, Charles F. "An instrumental earthquake magnitude scale." *Bulletin of the seismological society of America* 25.1 (1935): 1-32.
